===========
OSChameleon
===========

| **OS Fingerprint Obfuscation for modern Linux  Kernels.**
| *Author: Anton Hinterleitner is111012@fhstp.ac.at*

Description: Fools the probes of nmap scanner

Prerequisites: 
 * Linux
 * Python 2.6+
 * python-nfqueue (apt-get install python-nfqueue)
 * scapy (pip install -r requirements.txt)

**Note: This script flushes iptables before and after usage!**